==> honey-toolkit-1.0.31.tgz: package/fn/query.js <==
const path = require('path');
const fs = require('fs');
const transform = require('../util/transform');
const ncp = require('ncp').ncp;
const config = require('../config');
const getNames = require('../util/names').getNames;
const deleteFolder = require('../util/folder').deleteFolder;

const Page = function(){};

Page.deleteQuery = name => {
  const names = getNames(name);
  const { nameU ,nameC ,nameD ,name_ } = names;

  // query
  try{
		fs.unlinkSync(`./src/data/queries/${nameC}.js`);
  }catch (err){
    console.log('unlink failed:', err);
  }


  // schema.js
	var schema = fs.readFileSync('./src/data/schema.js', 'utf-8');
	schema = schema.replace(
		`import { querys as ${nameC}Qr, mutations as ${nameC}Mt } from './queries/${nameC}';
`, '')
    .replace(
      `      ...${nameC}Qr,
`,
      ''
    )
		.replace(
			`      ...${nameC}Mt,
`,
      ''
		);
	fs.writeFileSync(`./src/data/schema.js`, schema, { encoding:'utf-8', flag:'w' });

	// schema.graphql
	schema = fs.readFileSync(path.resolve('./src/data/schema.graphqls'), 'utf-8');
	schema.replace(
	  `  ${nameC}List:[Object]
  ${nameC}Count(filter:Object, skip:Int, limit:Int):Int        
  ${nameC}Update(${nameC}:${nameU}Input):Boolean`,
    ''
  ).replace(
		`  add${nameU}(${nameC}:${nameU}Input):{nameU}
  update${nameU}(${nameC}:${nameU}Input):Boolean
  delete${nameU}(_id:ID):Boolean
  delete${nameU}Many(_ids:[ID]):Boolean
`,
    ''
	).replace(
`input ${nameU}Input{
  _id: ID,
}

type ${nameU} {
  _id: ID,
}
`,
    ''
  );
	fs.writeFileSync(path.resolve('./src/data/schema.graphqls'), schema, { encoding:'utf-8', flag:'w' });

	// schema.graphqls
	schema = fs.readFileSync(path.resolve('./src/data/schema.graphqls'), 'utf-8');
	schema = schema
		.replace(
`  ${nameC}List:[Object]
  ${nameC}Count(filter:Object, skip:Int, limit:Int):Int
  ${nameC}(_id:ID):${nameU}
  
`,
      ''
		)
		.replace(
			`  add${nameU}(${nameC}:${nameU}Input):${nameU}
  update${nameU}(${nameC}:${nameU}Input):Boolean
  delete${nameU}(_id:ID):Boolean
  delete${nameU}Many(_ids:[ID]):Boolean

`,
      ''
		)
		.replace(
			// /(scalar DateTime\n)/,
			`
input ${nameU}Input{
  _id: ID,
}

type ${nameU} {
  _id: ID,
}
`,
      ''
		);
	fs.writeFileSync(path.resolve('./src/data/schema.graphqls'), schema, { encoding:'utf-8', flag:'w' });

	// delete ql
  deleteFolder(`./src/data/ql/${nameC}`);

  return names;
};

Page.createQuery = (name)=>{
  const names = getNames(name);
  const { nameU ,nameC ,nameD ,name_ } = names;

  // query.js
  var schema = fs.readFileSync(path.resolve(config.queryPath), 'utf-8');
  schema = schema
    .replace(/sampleQuery/g, nameC)
    .replace(/SampleQuery/g, nameU);
	fs.writeFileSync(path.resolve(`./src/data/queries/${nameC}.js`), schema, { encoding:'utf-8', flag:'w' });

    // schema.js
    schema = fs.readFileSync(path.resolve('./src/data/schema.js'), 'utf-8');
    schema = schema.replace(
      /([\s\S]* from '[^.].*';\n)/g,
      `$1import { querys as ${nameC}Qr, mutations as ${nameC}Mt } from './queries/${nameC}';
`).replace(
      /(Query: {\n)/,
      `$1      ...${nameC}Qr,
`
      )
      .replace(
        /(Mutation: {\n)/,
        `$1      ...${nameC}Mt,
`
      );
		fs.writeFileSync(path.resolve('./src/data/schema.js'), schema, { encoding:'utf-8', flag:'w' });

		// schema.graphqls
		schema = fs.readFileSync(path.resolve('./src/data/schema.graphqls'), 'utf-8');
		schema = schema
      .replace(
        /(type Query {\n)/,
        `$1  ${nameC}List:[Object]
  ${nameC}Count(filter:Object, skip:Int, limit:Int):Int
  ${nameC}(_id:ID):${nameU}
  
`,
      )
      .replace(
        /(type Mutation {\n)/,
        `$1  add${nameU}(${nameC}:${nameU}Input):${nameU}
  update${nameU}(${nameC}:${nameU}Input):Boolean
  delete${nameU}(_id:ID):Boolean
  delete${nameU}Many(_ids:[ID]):Boolean

`
      )
      .replace(
        /(scalar DateTime\n)/,
        `$1
input ${nameU}Input{
  _id: ID,
}

type ${nameU} {
  _id: ID,
}
`
      );
		fs.writeFileSync(path.resolve('./src/data/schema.graphqls'), schema, { encoding:'utf-8', flag:'w' });

  // ql
	ncp(
	  path.resolve('./templates/ql'),
		path.resolve('./src/data/ql/' + nameC),
		{
			/*transform: function (read, write){
				console.log('read:',read);
			}*/
		},
		function(err){
			if (err) {
				return console.error(err);
			} else {
				change();
			}
		}
	);

	function change(){
		function reName(path, ele){
			var toEle = ele.replace(/sampleQuery/g,nameC).replace(/SampleQuery/g,nameU);
			if(toEle !== ele){
				fs.renameSync(path+"/"+ele, path+"/"+toEle);
			}
			return toEle;
		}
		function readDirSync(path){
			var pa = fs.readdirSync(path);
			pa.forEach(function(ele,index){
				ele = reName(path, ele);
				var info = fs.statSync(path+"/"+ele)
				if(info.isDirectory()){
					readDirSync(path+"/"+ele);
				}else{
					var text = fs.readFileSync(`${path}/${ele}` ,'utf-8')
						.replace(/sampleQuery/g, nameC)
						.replace(/SampleQuery/g, nameU);
					fs.writeFileSync(`${path}/${ele}`, text, { encoding:'utf-8', flag:'w' });
				}
			})
		}
		readDirSync(path.resolve('./src/data/ql/' + nameC));
	}

  return names;
}
module.exports = Page;

==> honey-toolkit-1.0.32.tgz: package/fn/query.js <==
const path = require('path');
const fs = require('fs');
const transform = require('../util/transform');
const ncp = require('ncp').ncp;
const config = require('../config');
const getNames = require('../util/names').getNames;
const deleteFolder = require('../util/folder').deleteFolder;

const Page = function(){};

Page.deleteQuery = name => {
  const names = getNames(name);
  const { nameU ,nameC ,nameD ,name_ } = names;

  // query
  try{
		fs.unlinkSync(`./src/data/queries/${nameC}.js`);
  }catch (err){
    console.log('unlink failed:', err);
  }


  // schema.js
	var schema = fs.readFileSync('./src/data/schema.js', 'utf-8');
	schema = schema.replace(
		`import { querys as ${nameC}Qr, mutations as ${nameC}Mt } from './queries/${nameC}';
`, '')
    .replace(
      `      ...${nameC}Qr,
`,
      ''
    )
		.replace(
			`      ...${nameC}Mt,
`,
      ''
		);
	fs.writeFileSync(`./src/data/schema.js`, schema, { encoding:'utf-8', flag:'w' });

	// schema.graphqls delete
	schema = fs.readFileSync(path.resolve('./src/data/schema.graphqls'), 'utf-8');
	schema = schema
		.replace(
`  ${nameC}List(filter:Object, skip:Int, limit:Int):[${nameU}]
  ${nameC}Count(filter:Object):Int
  ${nameC}(_id:ID):${nameU}

`,
      ''
		)
		.replace(
`  add${nameU}(${nameC}:${nameU}Input):${nameU}
  update${nameU}(${nameC}:${nameU}Input):Boolean
  delete${nameU}(_id:ID):Boolean
  delete${nameU}Many(_ids:[ID]):Boolean

`,
      ''
		)
		.replace(
`
input ${nameU}Input{
  _id: ID,
}

type ${nameU} {
  _id: ID,
}
`,
      ''
		);
	fs.writeFileSync(path.resolve('./src/data/schema.graphqls'), schema, { encoding:'utf-8', flag:'w' });

	// delete ql
  deleteFolder(`./src/data/ql/${nameC}`);

  return names;
};

Page.createQuery = (name)=>{
  const names = getNames(name);
  const { nameU ,nameC ,nameD ,name_ } = names;

  // query.js
  var schema = fs.readFileSync(path.resolve(config.queryPath), 'utf-8');
  schema = schema
    .replace(/sampleQuery/g, nameC)
    .replace(/SampleQuery/g, nameU);
	fs.writeFileSync(path.resolve(`./src/data/queries/${nameC}.js`), schema, { encoding:'utf-8', flag:'w' });

    // schema.js
    schema = fs.readFileSync(path.resolve('./src/data/schema.js'), 'utf-8');
    schema = schema.replace(
      /([\s\S]* from '[^.].*';\n)/g,
      `$1import { querys as ${nameC}Qr, mutations as ${nameC}Mt } from './queries/${nameC}';
`).replace(
      /(Query: {\n)/,
      `$1      ...${nameC}Qr,
`
      )
      .replace(
        /(Mutation: {\n)/,
        `$1      ...${nameC}Mt,
`
      );
		fs.writeFileSync(path.resolve('./src/data/schema.js'), schema, { encoding:'utf-8', flag:'w' });

		// schema.graphqls create
		schema = fs.readFileSync(path.resolve('./src/data/schema.graphqls'), 'utf-8');
		schema = schema
      .replace(
        /(type Query {\n)/,
        `$1  ${nameC}List(filter:Object, skip:Int, limit:Int):[${nameU}]
  ${nameC}Count(filter:Object):Int
  ${nameC}(_id:ID):${nameU}

`,
      )
      .replace(
        /(type Mutation {\n)/,
        `$1  add${nameU}(${nameC}:${nameU}Input):${nameU}
  update${nameU}(${nameC}:${nameU}Input):Boolean
  delete${nameU}(_id:ID):Boolean
  delete${nameU}Many(_ids:[ID]):Boolean

`
      )
      .replace(
        /(scalar DateTime\n)/,
        `$1
input ${nameU}Input{
  _id: ID,
}

type ${nameU} {
  _id: ID,
}
`
      );
		fs.writeFileSync(path.resolve('./src/data/schema.graphqls'), schema, { encoding:'utf-8', flag:'w' });

  // ql
	ncp(
	  path.resolve('./templates/ql'),
		path.resolve('./src/data/ql/' + nameC),
		{
			/*transform: function (read, write){
				console.log('read:',read);
			}*/
		},
		function(err){
			if (err) {
				return console.error(err);
			} else {
				change();
			}
		}
	);

	function change(){
		function reName(path, ele){
			var toEle = ele.replace(/sampleQuery/g,nameC).replace(/SampleQuery/g,nameU);
			if(toEle !== ele){
				fs.renameSync(path+"/"+ele, path+"/"+toEle);
			}
			return toEle;
		}
		function readDirSync(path){
			var pa = fs.readdirSync(path);
			pa.forEach(function(ele,index){
				ele = reName(path, ele);
				var info = fs.statSync(path+"/"+ele)
				if(info.isDirectory()){
					readDirSync(path+"/"+ele);
				}else{
					var text = fs.readFileSync(`${path}/${ele}` ,'utf-8')
						.replace(/sampleQuery/g, nameC)
						.replace(/SampleQuery/g, nameU);
					fs.writeFileSync(`${path}/${ele}`, text, { encoding:'utf-8', flag:'w' });
				}
			})
		}
		readDirSync(path.resolve('./src/data/ql/' + nameC));
	}

  return names;
}
module.exports = Page;
